@@ -22,6 +22,7 @@
 
 /**
  * SECTION:gsttagxmp
+ * @title: GstXmptag
  * @short_description: tag mappings and support functions for plugins
  *                     dealing with xmp packets
  * @see_also: #GstTagList
@@ -1313,6 +1314,7 @@ gst_tag_list_from_xmp_buffer (GstBuffer * buffer)
                 }
                 if (ns_match[i].ns_prefix) {
                   if (strcmp (ns_map[i].original_ns, &as[6])) {
+                    g_free (ns_map[i].gstreamer_ns);
                     ns_map[i].gstreamer_ns = g_strdup (&as[6]);
                   }
                 }
